]> sigrok.org Git - libsigrok.git/blobdiff - device.c
sr: adjust copyright year
[libsigrok.git] / device.c
index 19fd6a14afba39af557889256e4b7182cae2bd8b..2713e68f2b6d9afa4f7416d7a7894ec639005a55 100644 (file)
--- a/device.c
+++ b/device.c
@@ -1,7 +1,7 @@
 /*
  * This file is part of the sigrok project.
  *
- * Copyright (C) 2010 Bert Vermeulen <bert@biot.com>
+ * Copyright (C) 2010-2012 Bert Vermeulen <bert@biot.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,14 +50,14 @@ static GSList *devices = NULL;
  * caller should not assume or rely on any specific order.
  *
  * After the system has been scanned for devices, the list of detected (and
* supported) devices can be acquired via sr_device_list().
  *
  * TODO: Error checks?
  * TODO: Option to only scan for specific devices or device classes.
  *
  * @return SR_OK upon success, SR_ERR upon errors.
  */
-SR_API int sr_device_scan(void)
+SR_API int sr_dev_scan(void)
 {
        GSList *plugins, *l;
        struct sr_device_plugin *plugin;
@@ -75,7 +75,7 @@ SR_API int sr_device_scan(void)
        for (l = plugins; l; l = l->next) {
                plugin = l->data;
                /* TODO: Handle 'plugin' being NULL. */
-               sr_init_hwplugins(plugin);
+               sr_init_hwplugin(plugin);
        }
 
        return SR_OK;
@@ -85,16 +85,16 @@ SR_API int sr_device_scan(void)
  * Return the list of logic analyzer devices libsigrok has detected.
  *
  * If the libsigrok-internal device list is empty, a scan for attached
* devices -- via a call to sr_device_scan() -- is performed first.
  *
  * TODO: Error handling?
  *
  * @return The list (GSList) of detected devices, or NULL if none were found.
  */
-SR_API GSList *sr_device_list(void)
+SR_API GSList *sr_dev_list(void)
 {
        if (!devices)
-               sr_device_scan();
+               sr_dev_scan();
 
        return devices;
 }
@@ -106,7 +106,7 @@ SR_API GSList *sr_device_list(void)
  * additionally a pointer to the newly created device is also returned.
  *
  * The device has no probes attached to it yet after this call. You can
* use sr_device_probe_add() to add one or more probes.
  *
  * TODO: Should return int, so that we can return SR_OK, SR_ERR_* etc.
  *
@@ -119,7 +119,7 @@ SR_API GSList *sr_device_list(void)
  *
  * @return Pointer to the newly allocated device, or NULL upon errors.
  */
-SR_API struct sr_device *sr_device_new(const struct sr_device_plugin *plugin,
+SR_API struct sr_device *sr_dev_new(const struct sr_device_plugin *plugin,
                                       int plugin_index)
 {
        struct sr_device *device;
@@ -138,90 +138,13 @@ SR_API struct sr_device *sr_device_new(const struct sr_device_plugin *plugin,
        return device;
 }
 
-/**
- * Clear all probes of the specified device.
- *
- * This removes/clears the 'name' and 'trigger' fields of all probes of
- * the device.
- *
- * The order in which the probes are cleared is not specified. The caller
- * should not assume or rely on a specific order.
- *
- * TODO: Rename to sr_device_clear_probes() or sr_device_probe_clear_all().
- *
- * @param device The device whose probes to clear. Must not be NULL.
- *               Note: device->probes is allowed to be NULL (in that case,
- *               there are no probes, thus none have to be cleared).
- *
- * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments.
- *         If something other than SR_OK is returned, 'device' is unchanged.
- */
-SR_API int sr_device_clear(struct sr_device *device)
-{
-       unsigned int pnum;
-
-       if (!device) {
-               sr_err("dev: %s: device was NULL", __func__);
-               return SR_ERR_ARG;
-       }
-
-       /* Note: device->probes can be NULL, this is handled correctly. */
-
-       for (pnum = 1; pnum <= g_slist_length(device->probes); pnum++)
-               sr_device_probe_clear(device, pnum);
-
-       return SR_OK;
-}
-
-/**
- * Clear the specified probe in the specified device.
- *
- * The probe itself still exists afterwards, but its 'name' and 'trigger'
- * fields are g_free()'d and set to NULL.
- *
- * @param device The device in which the specified (to be cleared) probe
- *               resides. Must not be NULL.
- * @param probenum The number of the probe to clear.
- *                 Note that the probe numbers start at 1 (not 0!).
- *
- * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments, or SR_ERR
- *         upon other errors.
- *         If something other than SR_OK is returned, 'device' is unchanged.
- */
-SR_API int sr_device_probe_clear(struct sr_device *device, int probenum)
-{
-       struct sr_probe *p;
-
-       if (!device) {
-               sr_err("dev: %s: device was NULL", __func__);
-               return SR_ERR_ARG;
-       }
-
-       /* TODO: Sanity check on 'probenum'. */
-
-       if (!(p = sr_device_probe_find(device, probenum))) {
-               sr_err("dev: %s: probe %d not found", __func__, probenum);
-               return SR_ERR; /* TODO: More specific error? */
-       }
-
-       /* If the probe has a name, remove it. */
-       g_free(p->name);
-       p->name = NULL;
-
-       /* If the probe has a trigger, remove it. */
-       g_free(p->trigger);
-       p->trigger = NULL;
-
-       return SR_OK;
-}
-
 /**
  * Add a probe with the specified name to the specified device.
  *
  * The added probe is automatically enabled (the 'enabled' field is TRUE).
  *
  * The 'trigger' field of the added probe is set to NULL. A trigger can be
- * added via sr_device_trigger_set().
+ * added via sr_dev_trigger_set().
  *
  * TODO: Are duplicate names allowed?
  * TODO: Do we enforce a maximum probe number for a device?
@@ -237,7 +160,7 @@ SR_API int sr_device_probe_clear(struct sr_device *device, int probenum)
  *         or SR_ERR_ARG upon invalid arguments.
  *         If something other than SR_OK is returned, 'device' is unchanged.
  */
-SR_API int sr_device_probe_add(struct sr_device *device, const char *name)
+SR_API int sr_dev_probe_add(struct sr_device *device, const char *name)
 {
        struct sr_probe *p;
        int probenum;
@@ -285,7 +208,7 @@ SR_API int sr_device_probe_add(struct sr_device *device, const char *name)
  * @return A pointer to the requested probe's 'struct sr_probe', or NULL
  *         if the probe could not be found.
  */
-SR_API struct sr_probe *sr_device_probe_find(const struct sr_device *device,
+SR_API struct sr_probe *sr_dev_probe_find(const struct sr_device *device,
                                             int probenum)
 {
        GSList *l;
@@ -328,7 +251,7 @@ SR_API struct sr_probe *sr_device_probe_find(const struct sr_device *device,
  *         upon other errors.
  *         If something other than SR_OK is returned, 'device' is unchanged.
  */
-SR_API int sr_device_probe_name(struct sr_device *device, int probenum,
+SR_API int sr_dev_probe_name(struct sr_device *device, int probenum,
                                const char *name)
 {
        struct sr_probe *p;
@@ -338,7 +261,7 @@ SR_API int sr_device_probe_name(struct sr_device *device, int probenum,
                return SR_ERR_ARG;
        }
 
-       p = sr_device_probe_find(device, probenum);
+       p = sr_dev_probe_find(device, probenum);
        if (!p) {
                sr_err("dev: %s: probe %d not found", __func__, probenum);
                return SR_ERR; /* TODO: More specific error? */
@@ -364,7 +287,7 @@ SR_API int sr_device_probe_name(struct sr_device *device, int probenum,
  * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments.
  *         If something other than SR_OK is returned, 'device' is unchanged.
  */
-SR_API int sr_device_trigger_clear(struct sr_device *device)
+SR_API int sr_dev_trigger_clear(struct sr_device *device)
 {
        struct sr_probe *p;
        unsigned int pnum; /* TODO: uint16_t? */
@@ -380,7 +303,7 @@ SR_API int sr_device_trigger_clear(struct sr_device *device)
        }
 
        for (pnum = 1; pnum <= g_slist_length(device->probes); pnum++) {
-               p = sr_device_probe_find(device, pnum);
+               p = sr_dev_probe_find(device, pnum);
                /* TODO: Silently ignore probes which cannot be found? */
                if (p) {
                        g_free(p->trigger);
@@ -407,7 +330,7 @@ SR_API int sr_device_trigger_clear(struct sr_device *device)
  *         upon other errors.
  *         If something other than SR_OK is returned, 'device' is unchanged.
  */
-SR_API int sr_device_trigger_set(struct sr_device *device, int probenum,
+SR_API int sr_dev_trigger_set(struct sr_device *device, int probenum,
                                 const char *trigger)
 {
        struct sr_probe *p;
@@ -421,7 +344,7 @@ SR_API int sr_device_trigger_set(struct sr_device *device, int probenum,
 
        /* TODO: Sanity check on 'trigger'. */
 
-       p = sr_device_probe_find(device, probenum);
+       p = sr_dev_probe_find(device, probenum);
        if (!p) {
                sr_err("dev: %s: probe %d not found", __func__, probenum);
                return SR_ERR; /* TODO: More specific error? */
@@ -449,7 +372,7 @@ SR_API int sr_device_trigger_set(struct sr_device *device, int probenum,
  *         FALSE is also returned upon invalid input parameters or other
  *         error conditions.
  */
-SR_API gboolean sr_device_has_hwcap(const struct sr_device *device, int hwcap)
+SR_API gboolean sr_dev_has_hwcap(const struct sr_device *device, int hwcap)
 {
        int *capabilities, i;
 
@@ -493,7 +416,7 @@ SR_API gboolean sr_device_has_hwcap(const struct sr_device *device, int hwcap)
  * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments, or SR_ERR
  *         upon other errors.
  */
-int sr_device_get_info(const struct sr_device *device, int id,
+int sr_dev_get_info(const struct sr_device *device, int id,
                                           const void **data)
 {
        if ((device == NULL) || (device->plugin == NULL))
@@ -50,14 +50,14 @@ static GSList *devices = NULL;
  *
  * After the system has been scanned for devices, the list of detected (and
- * supported) devices can be acquired via sr_device_list().
+ * supported) devices can be acquired via sr_dev_list().
  *
  * TODO: Error checks?
@@ -85,16 +85,16 @@ SR_API int sr_device_scan(void)
  *
  * If the libsigrok-internal device list is empty, a scan for attached
- * devices -- via a call to sr_device_scan() -- is performed first.
+ * devices -- via a call to sr_dev_scan() -- is performed first.
  *
  * TODO: Error handling?
@@ -106,7 +106,7 @@ SR_API GSList *sr_device_list(void)
  *
  * The device has no probes attached to it yet after this call. You can
- * use sr_device_probe_add() to add one or more probes.
+ * use sr_dev_probe_add() to add one or more probes.
  *
  * TODO: Should return int, so that we can return SR_OK, SR_ERR_* etc.